# jTWA: Truncated Wigner on GPUs based on [jax]

Welcome to the documentation of jTWA. jTWA implements the [Truncated Wigner Approximation](https://www.sciencedirect.com/science/article/abs/pii/S0003491610000382?via%3Dihub) in python using [jax], thus allowing to write easily understandable python code that is readily executed on GPUs.
For more information on [jax] see the [documentation](https://jax.readthedocs.io/en/latest/).

```{toctree}
:caption: Getting Started
:maxdepth: 1

docs/install
docs/quickstart
```   

```{toctree}
:caption: API Reference - General
:maxdepth: 1

docs/integrate
docs/util
docs/visualization
```   

```{toctree}
:caption: API Reference - Spin 1
:maxdepth: 1

docs/spin1
```   


[jax]: https://jax.readthedocs.io/en/latest/ "jax"
